@@ -69,20 +69,22 @@ class Tokenizer(tokenization_abc.Tokenization):
 
         self.corpus_ngrams = None
 
-    def ngrams2tokens(self, n: Union[int, Iterable[int]], docs_in:Iterable[Dict[str, str]], docs_out: Iterable[Dict[str, str]]=None, pos: Tuple[str, ...] = ("PROPN", "VERB", "NOUN", "ADJ"),
+    def ngrams2tokens(self, n: Union[int, Iterable[int]], docs_in: Iterable[Dict[str, str]],
+                      docs_out: Iterable[Dict[str, str]] = None,
+                      pos: Tuple[str, ...] = ("PROPN", "VERB", "NOUN", "ADJ"),
                       corpus_threshold: int = 50,
                       doc_threshold: int = 0,
-                      len_gram: int = 3, include: Tuple[str, ...] = None, replace: bool = True) -> Dict[int, str]:
+                      len_gram: int = 3, include: Tuple[str, ...] = None, replace: bool = True) -> List[Dict[int, str]]:
         """
         Calculates frequent n-grams in the corpus. They will be considered as unique tokens during the Tokenization task. <br/>
         Frequent n-grams will be calculated based on the documents in the input stream (docs_in). <br/>
         Frequent n-grams will be considered as unique tokens in the output stream documents (docs_out).
 
         Args:
-            docs_in (Iterable[Dict[str, str]]): Stream of input json documents as dicts. <br/> Each document must have a key where the text of the document is stored. Frequent ngrams will be calculated by scrolling this stream.
-            docs_out (Iterable[Dict[str, str]], optional, default=None): Stream of output json documents as dicts. <br/> Each document must have a key where the text of the document is stored. If not None, frequent ngrams will be considered as unique tokens for each document in the stream. Each document will be yielded as output of this function.
-            n (Union[int, Iterable[int]]): If int, the size of n-grams. (e.g. n=2, bigrams) <br/> If Iterable[int], the sizes of n-grams. (e.g. n=[2,3,5], bigrams, trigrams, fivegrams)
-            pos (Tuple[str, ...], optional): default ('PROPN', 'VERB', 'NOUN', 'ADJ'). <br/> Part of speech of the first and the last token that make up n-grams. <br/> Filters the most informative n-grams. <br/> If None, the filter will be ignored.
+           docs_in (Iterable[Dict[str, str]]): Stream of input json documents as dicts. <br/> Each document must have a key where the text of the document is stored. Frequent n-grams will be calculated by scrolling this stream.
+           docs_out (Iterable[Dict[str, str]]): Stream of output json documents as dicts. <br/> Each document must have a key where the text of the document is stored. Frequent n-grams will be considered as unique tokens for each document in the stream. Each document will be yielded as output of this function.
+           n (Union[int, Iterable[int]]): If int, the size of n-grams. (e.g. n=2, bigrams) <br/> If Iterable[int], the sizes of n-grams. (e.g. n=[2,3,5], bigrams, trigrams, fivegrams)
+           pos (Tuple[str, ...], optional): default ('PROPN', 'VERB', 'NOUN', 'ADJ'). <br/> Part of speech of the first and the last token that make up n-grams. <br/> Filters the most informative n-grams. <br/> If None, the filter will be ignored.
 
                    Example:
                    pos = ("PROPN", "VERB", "NOUN", "ADJ")
@@ -203,7 +205,8 @@ class Tokenizer(tokenization_abc.Tokenization):
                     doc[self.text_key] = doc[self.text_key].replace(ngram, ngram + ' ' + ngram.replace(' ', '_'))
             yield doc
 
-    def run(self, docs:Iterable[Dict[str, str]], doc_id: int = 0, token_id: int = 0, sent_id: int = 0, para_id: int = 0,
+    def run(self, docs: Iterable[Dict[str, str]], doc_id: int = 0, token_id: int = 0, sent_id: int = 0,
+            para_id: int = 0,
             para_size: int = 3, index_doc: bool = True, index_sent: bool = True,
             index_para: bool = True) -> Iterable[Dict[str, dict]]:
         """
@@ -223,47 +226,47 @@ class Tokenizer(tokenization_abc.Tokenization):
         Returns:
             Iterable[Dict[str, dict]]: Stream of tokens, sentences, paragraphs, documents records.
 
-                Example:
-                [index_sent == True, index_para == False, index_doc == True]
+                    Example:
+                    [index_sent == True, index_para == False, index_doc == True]
 
-                >>> t = Tokenizer(domain_stopwords=my_domain_stopwords)
-                >>> records = t.run(docs=my_docs):
-                >>> next(records).keys()
-                dict_keys(["tokens", "sentences", "documents"])
+                    >>> t = Tokenizer(domain_stopwords=my_domain_stopwords)
+                    >>> records = t.run(docs=my_docs):
+                    >>> next(records).keys()
+                    dict_keys(["tokens", "sentences", "documents"])
 
 
-                Example:
-                >>> record = next(records)
-                >>> tokens = record["tokens"]
-                >>> sentences = record["sentences"]
-                >>> print(tokens)
-                [
-                    {
-                    "token_id_": 0,
-                    "sent_id_": 0,
-                    "para_id_": 0,
-                    "doc_id_": 0,
-                    "text_": "When",
-                    "sent_pos_": 0,
-                    "para_pos_": 0,
-                    "doc_pos_": 0,
-                    "lower_": "when",
-                    ...
-                    },
-                    ...
-                ]
-                >>> print(sentences)
-                [
-                    {
-                     "sent_id_": 0,
-                     "text_": "When We , though all unworthy , were called to succeed on the Apostolic Throne the meek Pius X , whose life of holiness and well doing was cut short by grief -atti_degli_apostoli- the fratricidal struggle that had just burst forth in Europe , We , too , on turning a fearful glance on the blood stained battlefields , felt the anguish of a father , who sees his homestead devastated and in ruins before the fury of the hurricane .",
-                     "named_entities_": ["Apostolic Throne", "Pius X", "Europe"],
-                    ...
-                    }
-                ]
+                    Example:
+                    >>> record = next(records)
+                    >>> tokens = record["tokens"]
+                    >>> sentences = record["sentences"]
+                    >>> print(tokens)
+                    [
+                        {
+                        "token_id_": 0,
+                        "sent_id_": 0,
+                        "para_id_": 0,
+                        "doc_id_": 0,
+                        "text_": "When",
+                        "sent_pos_": 0,
+                        "para_pos_": 0,
+                        "doc_pos_": 0,
+                        "lower_": "when",
+                        ...
+                        },
+                        ...
+                    ]
+                    >>> print(sentences)
+                    [
+                        {
+                         "sent_id_": 0,
+                         "text_": "When We , though all unworthy , were called to succeed on the Apostolic Throne the meek Pius X , whose life of holiness and well doing was cut short by grief -atti_degli_apostoli- the fratricidal struggle that had just burst forth in Europe , We , too , on turning a fearful glance on the blood stained battlefields , felt the anguish of a father , who sees his homestead devastated and in ruins before the fury of the hurricane .",
+                         "named_entities_": ["Apostolic Throne", "Pius X", "Europe"],
+                        ...
+                        }
+                    ]
 
 
-            Check the config.ini file for records information.
+                Check the config.ini file for records information.
         """
 
         # list of sentences making up a paragraph
