@@ -183,47 +183,59 @@ class Vectorizer(vectorization.Vectorization):
                     ]
         """
 
-        filters = dict()
-        for k, v in self.nlp.config.config['Vector_filter'].items():
-            if v != 'None':
-                filters[k] = bool(int(v))
+        if not hasattr(self, 'tf_postings'):
+            filters = dict()
+            for k, v in self.nlp.config.config['Vector_filter'].items():
+                if v != 'None':
+                    filters[k] = bool(int(v))
 
-        def __filter__(__token__):
-            for key, value in {'dep_': dep, 'pos_': pos}.items():
-                if value is not None and len(value) != 0 and __token__[key] not in value:
+            def __filter__(__token__):
+                for key, value in {'dep_': dep, 'pos_': pos}.items():
+                    if value is not None and len(value) != 0 and __token__[key] not in value:
+                        return False
+
+                if len(__token__[self.token_field]) < min_len:
                     return False
 
-            if len(__token__[self.token_field]) < min_len:
-                return False
+                for key, value in filters.items():
+                    if not __token__[key + '_'] == value:
+                        return False
 
-            for key, value in filters.items():
-                if not __token__[key + '_'] == value:
+                if lang is not None and lang != __token__['lang_']:
                     return False
 
-            if lang is not None and lang != __token__['lang_']:
-                return False
+                return True
 
-            return True
+            postings = defaultdict(lambda: defaultdict(int))
+            for token in tqdm(tokens, desc="TF calculation in progress...", position=0, leave=True):
+                if not __filter__(token):
+                    continue
 
-        postings = defaultdict(lambda: defaultdict(int))
-        for token in tokens:
-            if not __filter__(token):
-                continue
+                key = " + ".join([token[g] for g in self.group_by_field])
 
-            key = " + ".join([token[g] for g in self.group_by_field])
-            if boolean:
-                postings[token[self.token_field]][key] = 1
-            else:
-                postings[token[self.token_field]][key] += 1
+                # replace . (ngrams like "commissione_._signore")
+                token_field = token[self.token_field].replace('.', '\u002E')
+                if boolean:
+                    postings[token_field][key] = 1
+                else:
+                    postings[token_field][key] += 1
 
-        for token in copy.deepcopy(postings):
-            if sum(postings[token].values()) < min_count:
-                del postings[token]
+            for token in copy.deepcopy(postings):
+                if sum(postings[token].values()) < min_count:
+                    del postings[token]
+
+            self.tf_postings = postings
 
         if format_ == 'postings-list':
-            return postings
+            return self.tf_postings
         else:
-            return self.postings2docterm(postings)
+            return self.postings2docterm(self.tf_postings)
+
+    def reset_tf(self):
+        """If present, removes the tf postings list from memory.
+         It will be re-calculated on the next run call."""
+        if hasattr(self, 'tf_postings'):
+            delattr(self, 'tf_postings')
 
     def tfidf(self, tokens: Iterable[dict], normalize=True,
               pos: Tuple[str, ...] = ("NOUN", "VERB", "PROPN", "NGRAM"),
@@ -410,7 +422,7 @@ class Vectorizer(vectorization.Vectorization):
         n_tokens = sum([sum(postings[token].values()) for token in postings])
 
         mi_postings = defaultdict(lambda :defaultdict(int))
-        for token in postings:
+        for token in tqdm(postings, desc="Mutual Information calculation in progress...", position=0, leave=True):
             posting = defaultdict(int, postings[token])
             for label in posting:
                 row = docterm[label]['bow']
